@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -26,7 +26,7 @@
 		       $rules $props $ratvars
 		       varlist genvar
 		       $gensumnum checkfactors $features featurel
-		       $weightlevels tellratlist $dontfactor
+		       tellratlist $dontfactor
 		       dispflag savefile $%% $error
 		       opers *ratweights $ratweights
 		       $stringdisp $lispdisp
@@ -264,8 +264,9 @@
       (dolist (u '(bindtest nonarray evfun evflag opers special mode))
 	(remprop x u))
       (dolist (u opers)
-	(if (and (remprop x u)
-		 (eq (get x 'operators) 'simpargs1))
+	(when (and (remprop x u)
+		 (let ((xopval (get x 'operators)))
+		   (or (eq xopval 'simpargs1) (eq xopval nil))))
 	    (remprop x 'operators)))
       (when (member x (cdr $props) :test #'equal)
 	(remprop x 'sp2)
@@ -332,20 +333,20 @@
 	      (mapc #'kill1 (cdr $infolists))
 	      (setq $ratvars '((mlist simp)) varlist nil genvar nil
 		    checkfactors nil greatorder nil lessorder nil $gensumnum 0
-		    $weightlevels '((mlist)) *ratweights nil $ratweights
+		    *ratweights nil $ratweights
 		    '((mlist simp))
 		    tellratlist nil $dontfactor '((mlist)) $setcheck nil)
 	      (killallcontexts))
 	     ((setq z (assoc x '(($inlabels . $inchar) ($outlabels . $outchar) ($linelabels . $linechar)) :test #'eq))
 	      (mapc #'(lambda (y) (remvalue y '$kill))
 		    (getlabels* (eval (cdr z)) nil)))
-	     ((and (eq (ml-typep x) 'fixnum) (not (< x 0))) (remlabels x))
+	     ((and (fixnump x) (>= x 0)) (remlabels x))
 	     ((atom x) (kill1-atom x))
-	     ((and (eq (caar x) 'mlist) (eq (ml-typep (cadr x)) 'fixnum)
+	     ((and (eq (caar x) 'mlist) (fixnump (cadr x))
 		   (or (and (null (cddr x))
-			    (setq x (append x (ncons (cadr x)))))
-		       (and (eq (ml-typep (caddr x)) 'fixnum)
-			    (not (> (cadr x) (caddr x))))))
+                         (setq x (append x (ncons (cadr x)))))
+                      (and (fixnump (caddr x))
+                         (not (> (cadr x) (caddr x))))))
 	      (let (($linenum (caddr x))) (remlabels (- (caddr x) (cadr x)))))
 	     ((setq z (mgetl (caar x) '(hashar array))) (remarrelem z x))
 	     ((and ($subvarp x)
@@ -481,7 +482,7 @@
        (setq inchar (getlabcharn $inchar)) ; Only the 1st alphabetic char. of $INCHAR is tested
        (setq timep $showtime grindp $grind)
        (do ((x x (cdr x)))( (null x))
-	 (cond ((eq (ml-typep (car x)) 'fixnum) (setq numbp (car x)))
+	 (cond ((fixnump (car x)) (setq numbp (car x)))
 	       ((eq (car x) '$all))
 	       ((eq (car x) '$slow) (setq slowp t))
 	       ((eq (car x) '$nostring) (setq nostringp t))
@@ -526,10 +527,10 @@
 
 (defun listargp (x)
   (let (high)
-    (if (and ($listp x) (eq (ml-typep (cadr x)) 'fixnum)
-	     (or (and (null (cddr x)) (setq high (cadr x)))
-		 (and (eq (ml-typep (setq high (caddr x))) 'fixnum)
-		      (not (> (cadr x) high)))))
+    (if (and ($listp x) (fixnump (cadr x))
+           (or (and (null (cddr x)) (setq high (cadr x)))
+              (and (fixnump (setq high (caddr x)))
+                 (not (> (cadr x) high)))))
 	(cons (cadr x) high))))
 
 (defmspec $alias (form)
@@ -544,9 +545,6 @@
   (cond ((nonsymchk x '$alias))
 	((nonsymchk y '$alias))
         ((eq x y) y) ; x is already the alias of y
-; Not needed. We return the alias immediately if we already have one.
-;	((not (eq (getcharn x 1) #\$))
-;	 (merror "-ed symbols may not be aliased. ~M" x))
 	((get x 'reversealias)
 	 (if (not (eq x y))
 	     (merror (intl:gettext "alias: ~M already has an alias.") x)))
@@ -573,8 +571,8 @@
 	((numberp x) x)
 	((null x) 'false)
 	((eq x t) 'true)
-    ((member (getcharn x 1) '(#\$ #\%))
-     (intern (subseq (string x) 1)))
+        ((member (get-first-char x) '(#\$ #\%) :test #'char=)
+         (intern (subseq (string x) 1)))
 	(t x)))
 
 (defmfun fullstrip (x)
@@ -666,7 +664,8 @@
   (cond
     ((symbolp name) name)
     ((stringp name)
-     (getalias (or (getopr0 name) (implode (cons #\$ (coerce name 'list))))))))
+     (getalias (or (getopr0 name) (implode (cons #\$ (coerce name 'list))))))
+    (t name)))
 
 (defmspec $stringout (x)
   (setq x (cdr x))
@@ -727,7 +726,7 @@
 
 (defmfun $%th (x)
   (prog (l outchar)
-     (if (or (not (eq (ml-typep x) 'fixnum)) (= x 0))
+     (if (or (not (fixnump x)) (zerop x))
 	 (improper-arg-err x '$%th))
      (if (> x 0) (setq x (- x)))
      (if (cdr $labels)
@@ -769,11 +768,22 @@
 	c)))
 
 (defmspec $errcatch (form)
-  (let ((errcatch (cons bindlist loclist)) ret)
-    (if (null (setq ret (let (*mdebug*)
-			  (errset (rat-error-to-merror (mevaln (cdr form))) lisperrprint))))
-	(errlfun1 errcatch))
-    (cons '(mlist) ret)))
+  (let ((errcatch (cons bindlist loclist))
+        (*mdebug* nil))
+    (handler-case (list '(mlist) (rat-error-to-merror (mevaln (cdr form))))
+      (maxima-$error ()
+        ; merror already set the error variable and printed the error
+        ; message if errormsg is true, so we just need to clean up.
+        (errlfun1 errcatch)
+        (list '(mlist simp)))
+      (error (e)
+        ; We store the error report message in the error variable and
+        ; print the message if errormsg is true.  Then we clean up.
+        (setq $error (list '(mlist simp) (princ-to-string e)))
+        (when $errormsg
+          ($errormsg))
+        (errlfun1 errcatch)
+        (list '(mlist simp))))))
 
 (defmspec $catch (form)
   (let ((mcatch (cons bindlist loclist)))
@@ -811,7 +821,8 @@
 ;; File-processing stuff.
 
 (defmfun mterpri ()
-   (terpri))
+   (terpri)
+   (force-output))
 
 (defmspec $status (form)
   (setq form (cdr form))
